#---------------------------------------------------------------------------
# Copyright 2013 PwC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#---------------------------------------------------------------------------

## @class REG_IEMHV_Actions
## Registration/ADT Actions 

'''
Registration/ADT Actions class. Extends Actions

Created on  March 18 2015
@author: Brian Tomlin
@copyright PwC
@license http://www.apache.org/licenses/LICENSE-2.0
'''

import time,sys,re
import TestHelper
from Actions import Actions
import logging
import datetime

class REG_IEMHV_Actions (Actions):
    '''
    This class extends the Actions class with methods specific to actions performed
    through the Roll and Scroll interface for the Registration package.
    '''
    def __init__(self, VistAconn, scheduling=None, user=None, code=None):
        Actions.__init__(self, VistAconn, scheduling, user, code)

    def signon (self):
        ''' This provides a signon via ^XUP or ^ZU depending on the value of acode'''
        if self.acode is None:
            self.VistA.write('S DUZ=1,DUZ(0)="@",^XUSEC("DGPRE EDIT",DUZ,1)="" D ^XUP')
        else:
            self.VistA.write('S ^XUSEC("DGPRE EDIT",DUZ,1)="" D ^ZU')
            self.VistA.wait('ACCESS CODE:')
            self.VistA.write(self.acode)
            self.VistA.wait('VERIFY CODE:')
            self.VistA.write(self.vcode)
            self.VistA.wait('//')
            self.VistA.write('')
            self.VistA.wait('Option:')
            self.VistA.write('ADT MANAGER MENU')
            self.VistA.wait('continue')
            self.VistA.write('')

    def priortime(self, deltamin= -1):
        '''Return a previous time '''
        ttime = datetime.datetime.now() + datetime.timedelta(minutes=deltamin)
        return ttime.strftime("%I:%M%p").lstrip('0')

    def write(self, string):
        self.VistA.write(string)

    def multiwait(self, options, tout=15):
        logging.debug('connection.expect: ' + str(options))
        if isinstance(options, list):
            index = self.connection.expect(options, tout)
            if index == -1:
                logging.debug('ERROR: expected: ' + options)
                raise TestHelper.TestError('ERROR: expected: ' + options)
            self.connection.logfile_read.write(options[index])
            self.lastconnection=self.connection.before
            return index
        else:
            raise IndexError('Input to multiwait function is not a list')


    def pre_reg_tc_1_step_1to2(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        # STEP 1
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        # STEP 2
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)

    def pre_reg_tc_1_step_3to8(self):
        # STEP 3 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Recent My HealtheVet actions taken by VistA Clerks')
        self.VistA.wait('- NONE -')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('response:')
        # STEP 4
        self.VistA.write('2')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team."')
        self.VistA.wait('Press RETURN to continue:')
        # STEP 5
        self.VistA.write('')
        # STEP 6 - (Verify)
        self.VistA.wait('Action(s) taken today to assist patient with My HealtheVet enrollment.')
        self.VistA.wait('Helped patient to create a MHV account')
        self.VistA.wait('Referred patient to the MHV office/station for assistance with')
        self.VistA.wait('Scheduled future appointment for patient to enroll at MHV office')
        self.VistA.wait('Gave patient MHV enrollment instructions to complete at a MH')
        self.VistA.wait('Patient had a MHV account issue. Provided MHV Help Desk toll')
        self.VistA.wait('free #1-877-327- 0022, Mon-Fri, 8 a.m.-8 p.m. (EST)')
        self.VistA.wait('Select an action:')
        self.VistA.write('?')
        self.VistA.wait('Select an action:')
        self.VistA.write('4')
        self.VistA.wait('A)dd another, (D)elete an action, or <RET> to save and exit:')
        self.VistA.write('')
        # STEP 7
        self.VistA.wait('exit:')
        # STEP 8
        self.VistA.write('^')

    def pre_reg_tc_1_step_9to11(self):
        ''' Pre-Register a new Patient and confirmed enrolled HealtheVet Questions'''
        # STEP 9 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('My HealtheVet actions taken by VistA Clerks')
        self.VistA.wait('Gave patient MHV enrollment instructions to complete at a')
        self.VistA.wait('MHV kiosk/computer.')
        while True:
            index = self.VistA.multiwait(['Press RETURN to continue','Were you able to create a My HealtheVet account from'])
            if index == 0:
                self.VistA.write('')
            else:
                break
        self.VistA.wait('the enrollment instructions we gave you last time?')
        self.VistA.write('N')
        self.VistA.wait('')
        # STEP 10 - (Verify)
        self.VistA.wait('Select an action:')
        self.VistA.write('1')
        # STEP 11
        self.VistA.wait('exit:')
        self.VistA.write('^')

    def pre_reg_tc_1_step_12to16(self):
        ''' Pre-Register a new Patient and confirmed enrolled HealtheVet Questions'''
        # STEP 12 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('My HealtheVet actions taken by VistA Clerks')
        self.VistA.wait('Gave patient MHV enrollment instructions to complete at a')
        self.VistA.wait('MHV kiosk/computer.')
        self.VistA.wait('Were you able to create a My HealtheVet account from')
        self.VistA.wait('the enrollment instructions we gave you last time?')
        self.VistA.write('Y')
        # STEP 13 - (Verify)
        self.VistA.wait('Enrolled: YES')
        self.VistA.wait('Authenticated: UNANSWERED')
        self.VistA.wait('Secure Messaging: UNANSWERED')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('2')
        # STEP 14
        self.VistA.wait('Step 2 of 3: My HealtheVet Authentication Upgrade')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With an Authenticated MHV account patients can view VA appointments,')
        self.VistA.wait('lab results and VA medical records online."')
        self.VistA.wait('Select (Y) YES if patient already has an Authenticated MHV account')
        self.VistA.wait('Select (A) ACTION if patient would like to upgrade to Authenticated MHV account.')
        self.VistA.wait('Select (N) NO if patient refuses an Authenticated MHV account.')
        self.VistA.wait('(Yes/No/(A)ction):')
        self.VistA.write('YES')
        self.VistA.wait('Step 3 of 3: My HealtheVet Secure Messaging')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With Secure Messaging, Veterans can communicate online with VA health')
        self.VistA.wait('care teams about health questions, to request prescription renewals,')
        self.VistA.wait('or schedule appointments."')
        self.VistA.wait('Secure Messaging? (Yes/No/(A)ction):')
        self.VistA.write('YES')
        self.VistA.wait('Enrolled: YES')
        self.VistA.wait('Authenticated: YES')
        self.VistA.wait('Secure Messaging: YES')
        # STEP 15
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        # STEP 16
        self.VistA.wait('exit:')
        self.VistA.write('^')

    def pre_reg_tc_1_step_17to18(self):
        # STEP 17 - (Verify)
        self.VistA.wait('Enrolled: YES')
        self.VistA.wait('Authenticated: YES')
        self.VistA.wait('Secure Messaging: YES')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        # STEP 18
        self.VistA.wait('exit:')
        self.VistA.write('^')

    def pre_reg_tc_1_step_19to26(self):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        # STEP 19
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Recent My HealtheVet actions taken by VistA Clerks')
        self.VistA.wait('- NONE -')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('response:')
        self.VistA.write('1')
        # STEP 20
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team."')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('Enrolled: YES')
        # STEP 21
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('2')
        self.VistA.wait('Step 2 of 3: My HealtheVet Authentication Upgrade')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With an Authenticated MHV account patients can view VA appointments,')
        self.VistA.wait('lab results and VA medical records online.')
        self.VistA.wait('Select (Y) YES if patient already has an Authenticated MHV account.')
        self.VistA.wait('Select (A) ACTION if patient would like to upgrade to Authenticated MHV account.')
        self.VistA.wait('Select (N) NO if patient refuses an Authenticated MHV account.')
        # STEP 22
        self.VistA.write('A')
        # STEP 23
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 24
        self.VistA.wait('Select an action:')
        self.VistA.write('4')
        self.VistA.wait('exit:')
        self.VistA.write('')
        self.VistA.wait('Authenticated: ACTION/IN PROGRESS')
        # STEP 25
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        # STEP 26
        self.VistA.wait('exit:')
        self.VistA.write('^')


    def pre_reg_tc_1_step_27to32(self):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        # STEP 27 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Recent My HealtheVet actions taken by VistA Clerks')
        self.VistA.wait('MHV Enrollment confirmed')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 28
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('2')
        self.VistA.wait('Step 2 of 3: My HealtheVet Authentication Upgrade')
        self.VistA.wait('Please read the following to the patient')
        # STEP 29
        self.VistA.wait('(Yes/No/(A)ction):')
        self.VistA.write('N')
        # STEP 29
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 30
        self.VistA.wait('Select reason patient has not upgraded/authenticated:')
        self.VistA.write('2')
        self.VistA.wait('Authenticated: NO')
        # STEP 31
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        # STEP 32
        self.VistA.wait('exit:')
        self.VistA.write('^')

    def pre_reg_tc_1_step_33to34(self):
        # STEP 33 - (Verify)
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('exit:')
        self.VistA.write('^')

    def pre_reg_tc_1_step_Delete_Reason(self):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('2')
        self.VistA.wait('Step 2 of 3: My HealtheVet Authentication Upgrade')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With an Authenticated MHV account patients can view VA appointments,')
        self.VistA.wait('lab results and VA medical records online."')
        self.VistA.wait('Select (Y) YES if patient already has an Authenticated MHV account')
        self.VistA.wait('Select (A) ACTION if patient would like to upgrade to Authenticated MHV account.')
        self.VistA.wait('Select (N) NO if patient refuses an Authenticated MHV account.')
        self.VistA.wait('(Yes/No/(A)ction):')
        self.VistA.write('YES')
        self.VistA.wait('Step 3 of 3: My HealtheVet Secure Messaging')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With Secure Messaging, Veterans can communicate online with VA health')
        self.VistA.wait('care teams about health questions, to request prescription renewals,')
        self.VistA.wait('or schedule appointments."')
        self.VistA.wait('Secure Messaging? (Yes/No/(A)ction):')
        self.VistA.write('NO')
        self.VistA.wait('Select reason not using secure messaging:')
        self.VistA.write('^')
        self.VistA.wait('Are you sure you want to quit')
        self.VistA.write('Y')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('exit:')
        self.VistA.write('^')


    def pre_reg_tc_1_step_37to38(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('D CLEAR^DGMHV')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('DO ##class(%SYSTEM.Process).FixedDate(0)')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('DO ##class(%SYSTEM.Process).FixedDate($$FMTH^XLFDT($$FMADD^XLFDT($$NOW^XLFDT,180)))')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('W !,"System Date has been changed to ",$$FMTE^XLFDT($$FMADD^XLFDT($$NOW^XLFDT,180))')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('D ^XUP')
        self.VistA.wait('OPTION NAME:')
        # STEP 1
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        # STEP 2
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 37 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('MHV Enrollment confirmed')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('exit:')
        self.VistA.write('^')
        self.VistA.write('')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('D CLEAR^DGMHV')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('DO ##class(%SYSTEM.Process).FixedDate($$FMTH^XLFDT($$NOW^XLFDT))')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('W !,"System Date has been restored to ",$$FMTE^XLFDT($$NOW^XLFDT)')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('D ^XUP')


    def pre_reg_tc_2(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 1 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 2 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('Yes - I am already enrolled.')
        self.VistA.wait('Yes - I would like to enroll.')
        self.VistA.wait('Yes - But I do not want to enroll right now.')
        self.VistA.wait('No - No one has spoken to me/I')
        self.VistA.wait('No - I am not interested in enrolling.')
        self.VistA.wait('have a computer / internet access')
        self.VistA.wait('response:')
        self.VistA.write('1')
        # STEP 3 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team."')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 4 - (Verify)
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
       # STEP 5 - (Verify)
        self.VistA.wait('exit:')
        self.VistA.write('^')


    def pre_reg_tc_3(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 1 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 2 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('Yes - I am already enrolled.')
        self.VistA.wait('Yes - I would like to enroll.')
        self.VistA.wait('Yes - But I do not want to enroll right now.')
        self.VistA.wait('No - No one has spoken to me/I ')
        self.VistA.wait('No - I am not interested in enrolling.')
        self.VistA.wait('have a computer / internet access')
        self.VistA.wait('response:')
        self.VistA.write('2')
        # STEP 3 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team."')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 4 - (Verify)
        self.VistA.wait('Action(s) taken today to assist patient with My HealtheVet enrollment.')
        self.VistA.wait('Helped patient to create a MHV account')
        self.VistA.wait('Referred patient to the MHV office/station for assistance with')
        self.VistA.wait('Scheduled future appointment for patient to enroll at MHV office')
        self.VistA.wait('Gave patient MHV enrollment instructions to complete at a MH')
        self.VistA.wait('Patient had a MHV account issue. Provided MHV Help Desk toll')
        self.VistA.wait('free #1-877-327- 0022, Mon-Fri, 8 a.m.-8 p.m. (EST)')
        self.VistA.wait('Select an action:')
        self.VistA.write('4')
        # STEP 5 - (Verify)
        self.VistA.wait('Gave patient MHV enrollment instructions to complete at a')
        self.VistA.wait('MHV kiosk/computer')
        self.VistA.wait('(A)dd another, (D)elete an action, or <RET> to save and exit:')
        self.VistA.write('D')
        self.VistA.write('4')
        self.VistA.write('')
        # STEP 6 - (Verify)
        self.VistA.wait('Action(s) taken today to assist patient with My HealtheVet enrollment.')
        self.VistA.wait('Helped patient to create a MHV account')
        self.VistA.wait('Referred patient to the MHV office/station for assistance with')
        self.VistA.wait('Scheduled future appointment for patient to enroll at MHV office')
        self.VistA.wait('Gave patient MHV enrollment instructions to complete at a MH')
        self.VistA.wait('Patient had a MHV account issue. Provided MHV Help Desk toll')
        self.VistA.wait('free #1-877-327- 0022, Mon-Fri, 8 a.m.-8 p.m. (EST)')
        self.VistA.wait('Select an action:')
        self.VistA.write('1')
        # STEP 7 - (Verify)
        self.VistA.wait('Helped patient to create a MHV account.')
        self.VistA.wait('(A)dd another, (D)elete an action, or <RET> to save and exit:')
        self.VistA.write('')
        self.VistA.wait('exit:')
        self.VistA.write('^')


    def pre_reg_tc_4(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 1 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 2 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('Yes - I am already enrolled.')
        self.VistA.wait('Yes - I would like to enroll.')
        self.VistA.wait('Yes - But I do not want to enroll right now.')
        self.VistA.wait('No - No one has spoken to me/I ')
        self.VistA.wait('No - I am not interested in enrolling.')
        self.VistA.wait('have a computer / internet access')
        self.VistA.wait('response:')
        self.VistA.write('3')
        # STEP 3 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team.')
        self.VistA.wait('I will give you some easy-to-follow instructions to take home and')
        self.VistA.wait('enroll or I can schedule a time for you to enroll with a My HealtheVet')
        self.VistA.wait('assistant. Once registered you will need to return to a VA clinic and sign')
        self.VistA.wait('a release of information form. Photo ID required. (Instructions for')
        self.VistA.wait('optional online Authentication process are also available)"')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 4 - (Verify)
        self.VistA.wait('Action(s) taken today to assist patient with My HealtheVet enrollment.')
        self.VistA.wait('Helped patient to create a MHV account')
        self.VistA.wait('Referred patient to the MHV office/station for assistance with')
        self.VistA.wait('Scheduled future appointment for patient to enroll at MHV office')
        self.VistA.wait('Gave patient MHV enrollment instructions to complete at a MH')
        self.VistA.wait('Patient had a MHV account issue. Provided MHV Help Desk toll')
        self.VistA.wait('free #1-877-327- 0022, Mon-Fri, 8 a.m.-8 p.m. (EST)')
        self.VistA.wait('Select an action:')
        self.VistA.write('^')
        # STEP 5 - (Verify)
        self.VistA.wait('Are you sure you want to quit ?')
        self.VistA.write('Y')
        self.VistA.wait('exit:')
        self.VistA.write('^')


    def pre_reg_tc_5(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 1 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 2 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('Yes - I am already enrolled.')
        self.VistA.wait('Yes - I would like to enroll.')
        self.VistA.wait('Yes - But I do not want to enroll right now.')
        self.VistA.wait('No - No one has spoken to me/I ')
        self.VistA.wait('No - I am not interested in enrolling.')
        self.VistA.wait('have a computer / internet access')
        self.VistA.wait('response:')
        self.VistA.write('4')
        # STEP 3 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team.')
        self.VistA.wait('I will give you some easy-to-follow instructions to take home and enroll')
        self.VistA.wait('or I can schedule a time for you to enroll with a My HealtheVet assistant.')
        self.VistA.wait('Once registered you will need to return to a VA clinic and sign a release')
        self.VistA.wait('of information form. Photo ID required. (Instructions for optional')
        self.VistA.wait('online Authentication process are also available)"')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 4 - (Verify)
        self.VistA.wait('Action(s) taken today to assist patient with My HealtheVet enrollment.')
        self.VistA.wait('Helped patient to create a MHV account')
        self.VistA.wait('Referred patient to the MHV office/station for assistance with')
        self.VistA.wait('Scheduled future appointment for patient to enroll at MHV office')
        self.VistA.wait('Gave patient MHV enrollment instructions to complete at a MH')
        self.VistA.wait('Patient had a MHV account issue. Provided MHV Help Desk toll')
        self.VistA.wait('free #1-877-327- 0022, Mon-Fri, 8 a.m.-8 p.m. (EST)')
        self.VistA.wait('Select an action:')
        self.VistA.write('^')
        # STEP 5
        self.VistA.wait('Are you sure you want to quit ?')
        self.VistA.write('Y')
        # STEP 6
        self.VistA.wait('exit:')
        self.VistA.write('^')

    def pre_reg_tc_6(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 1 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 2 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('Yes - I am already enrolled.')
        self.VistA.wait('Yes - I would like to enroll.')
        self.VistA.wait('Yes - But I do not want to enroll right now.')
        self.VistA.wait('No - No one has spoken to me/I ')
        self.VistA.wait('No - I am not interested in enrolling.')
        self.VistA.wait('have a computer / internet access')
        self.VistA.wait('response:')
        self.VistA.write('5')
        # STEP 3 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team.')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 4 - (Verify)
        self.VistA.wait('How does the patient feel now about enrolling in My HealtheVet?')
        self.VistA.wait('a) Patient is not interested.')
        self.VistA.wait('b) Patient is interested.')
        self.VistA.wait('Select a response:')
        self.VistA.write('b')
        # STEP 5
        self.VistA.wait('Action(s) taken today to assist patient with My HealtheVet enrollment.')
        self.VistA.wait('Helped patient to create a MHV account')
        self.VistA.wait('Referred patient to the MHV office/station for assistance with')
        self.VistA.wait('Scheduled future appointment for patient to enroll at MHV office')
        self.VistA.wait('Gave patient MHV enrollment instructions to complete at a MH')
        self.VistA.wait('Patient had a MHV account issue. Provided MHV Help Desk toll')
        self.VistA.wait('free #1-877-327- 0022, Mon-Fri, 8 a.m.-8 p.m. (EST)')
        self.VistA.wait('Select an action:')
        self.VistA.write('^')
        # STEP 6
        self.VistA.wait('Are you sure you want to quit ?')
        self.VistA.write('Y')
        # STEP 7
        self.VistA.wait('exit:')
        self.VistA.write('^')

    def pre_reg_tc_7(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 1 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 2 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('Yes - I am already enrolled.')
        self.VistA.wait('Yes - I would like to enroll.')
        self.VistA.wait('Yes - But I do not want to enroll right now.')
        self.VistA.wait('No - No one has spoken to me/I ')
        self.VistA.wait('No - I am not interested in enrolling.')
        self.VistA.wait('have a computer / internet access')
        self.VistA.wait('response:')
        self.VistA.write('5')
        # STEP 3 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team.')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 4 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Are you aware that a MyHealtheVet account allows you to view your VA')
        self.VistA.wait('appointments, Lab results, and access medical records? You can refill and')
        self.VistA.wait('track prescription deliveries and communicate securely with your Health')
        self.VistA.wait('care teams."')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('How does the patient feel now about enrolling in MyHealtheVet?')
        self.VistA.wait('a) Patient is not interested.')
        self.VistA.wait('b) Patient is interested.')
        self.VistA.wait('Select an response:')
        self.VistA.write('a')
        # STEP 5
        self.VistA.wait('Enrolled: UNANSWERED')
        self.VistA.write('^')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
       # STEP 6
        self.VistA.wait('exit:')
        self.VistA.write('^')


    def pre_reg_tc_8(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 1 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 2 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('Yes - I am already enrolled.')
        self.VistA.wait('Yes - I would like to enroll.')
        self.VistA.wait('Yes - But I do not want to enroll right now.')
        self.VistA.wait('No - No one has spoken to me/I ')
        self.VistA.wait('No - I am not interested in enrolling.')
        self.VistA.wait('have a computer / internet access')
        self.VistA.wait('response:')
        self.VistA.write('6')
        # STEP 3 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Do family or friends, who have a computer, ever help with your VA')
        self.VistA.wait('appointments or medications? You can also log on to any public library')
        self.VistA.wait('computer to use My HealtheVet. Imagine that you are out of town and you')
        self.VistA.wait('need a copy of your health records or medications-with a My HealtheVet')
        self.VistA.wait('account you can get them easily from any computer')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 4 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Are you aware that a MyHealtheVet account allows you to view your VA')
        self.VistA.wait('appointments, Lab results, and access medical records? You can refill and')
        self.VistA.wait('track prescription deliveries and communicate securely with your Health')
        self.VistA.wait('care teams."')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('How does the patient feel now about enrolling in MyHealtheVet?')
        self.VistA.wait('a) Patient is not interested.')
        self.VistA.wait('b) Patient is interested.')
        self.VistA.wait('Select an response:')
        self.VistA.write('b')
        # STEP 5
        self.VistA.wait('Action(s) taken today to assist patient with My HealtheVet enrollment.')
        self.VistA.wait('Helped patient to create a MHV account')
        self.VistA.wait('Referred patient to the MHV office/station for assistance with')
        self.VistA.wait('Scheduled future appointment for patient to enroll at MHV office')
        self.VistA.wait('Gave patient MHV enrollment instructions to complete at a MH')
        self.VistA.wait('Patient had a MHV account issue. Provided MHV Help Desk toll')
        self.VistA.wait('free #1-877-327- 0022, Mon-Fri, 8 a.m.-8 p.m. (EST)')
        self.VistA.wait('Select an action:')
        self.VistA.write('^')
        # STEP 6
        self.VistA.wait('Are you sure you want to quit ?')
        self.VistA.write('Y')
        # STEP 7
        self.VistA.wait('exit:')
        self.VistA.write('^')

    def pre_reg_tc_9(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 1 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 2 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('Yes - I am already enrolled.')
        self.VistA.wait('Yes - I would like to enroll.')
        self.VistA.wait('Yes - But I do not want to enroll right now.')
        self.VistA.wait('No - No one has spoken to me/I ')
        self.VistA.wait('No - I am not interested in enrolling.')
        self.VistA.wait('have a computer / internet access')
        self.VistA.wait('response:')
        self.VistA.write('1')
        # STEP 3 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team."')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('Enrolled: YES')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('1')
        # STEP 4
        self.VistA.wait('Step 1 of 3: My HealtheVet Enrollment')
        self.VistA.wait('Is the patient enrolled in My HealtheVet')
        self.VistA.write('NO')
        # STEP 5
        self.VistA.wait('1 - No one has spoken to me/I ')
        self.VistA.wait('2 - I am not interested.')
        self.VistA.wait('3 - I do not have a computer.')
        self.VistA.wait('4 - I do not have access to the internet')
        self.VistA.wait('5 - I do not trust the internet.')
        self.VistA.wait('6 - My caregiver makes these decisions for me.')
        self.VistA.wait('7 - I do not see the benefit.')
        self.VistA.wait('8 - I would not use it often enough.')
        self.VistA.wait('9 - Other')
        self.VistA.wait('Select reason patient is not enrolled:')
        self.VistA.write('3')
        # STEP 6 - (Verify)
        self.VistA.wait('Authenticated: NO')
        self.VistA.wait('Secure Messaging: NO')
        self.VistA.wait('Reason: I do not have a computer.')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        # STEP 7
        self.VistA.wait('exit:')
        self.VistA.write('^')


    def pre_reg_tc_10_step_1to13(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 1 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 2 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('Yes - I am already enrolled.')
        self.VistA.wait('Yes - I would like to enroll.')
        self.VistA.wait('Yes - But I do not want to enroll right now.')
        self.VistA.wait('No - No one has spoken to me/I ')
        self.VistA.wait('No - I am not interested in enrolling.')
        self.VistA.wait('have a computer / internet access')
        self.VistA.wait('response:')
        self.VistA.write('1')
        # STEP 3
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team."')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('Enrolled: YES')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('2')
        # STEP 4
        self.VistA.wait('Step 2 of 3: My HealtheVet Authentication Upgrade')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With an Authenticated MHV account patients can view VA appointments,')
        self.VistA.wait('lab results and VA medical records online."')
        self.VistA.wait('Select (Y) YES if patient already has an Authenticated MHV account')
        self.VistA.wait('Select (A) ACTION if patient would like to upgrade to Authenticated MHV account.')
        self.VistA.wait('Select (N) NO if patient refuses an Authenticated MHV account.')
        self.VistA.wait('(Yes/No/(A)ction):')
        self.VistA.write('N')
        # STEP 5
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('Upgrade to an Authenticated My HealtheVet account to view')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 6
        self.VistA.wait('9 - Other')
        self.VistA.wait('Select reason patient has not upgraded/authenticated:')
        self.VistA.write('9')
        self.VistA.wait('Other Reason Text')
        self.VistA.write('Something')
        self.VistA.wait('Authenticated: NO')
        # STEP 7 (Verify)
        self.VistA.wait('Reason: Other - Something')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('2')
        # STEP 8
        self.VistA.wait('Step 2 of 3: My HealtheVet Authentication Upgrade')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With an Authenticated MHV account patients can view VA appointments,')
        self.VistA.wait('lab results and VA medical records online."')
        self.VistA.wait('Select (Y) YES if patient already has an Authenticated MHV account')
        self.VistA.wait('Select (A) ACTION if patient would like to upgrade to Authenticated MHV account.')
        self.VistA.wait('Select (N) NO if patient refuses an Authenticated MHV account.')
        self.VistA.wait('(Yes/No/(A)ction):')
        self.VistA.write('A')
        # STEP 9
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('Upgrade to an Authenticated My HealtheVet account to view')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 10
        self.VistA.wait('Select an action:')
        self.VistA.write('1')
        # STEP 11
        self.VistA.wait('Patient signed MHV authentication form.')
        self.VistA.write('')
        # STEP 12
        self.VistA.wait('Action: Patient signed MHV authentication form.')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        # STEP 13
        self.VistA.wait('exit:')
        self.VistA.write('^')


    def pre_reg_tc_10_step_14to16(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 14 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Recent My HealtheVet actions taken by VistA Clerks')
        self.VistA.wait('MHV Enrollment confirmed')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 15
        self.VistA.wait('Enrolled: YES')
        self.VistA.wait('Authenticated: ACTION/IN PROGRESS')
        self.VistA.wait('Action: Patient signed MHV authentication form.')
        self.VistA.wait('Secure Messaging: UNANSWERED')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        # STEP 16
        self.VistA.wait('exit:')
        self.VistA.write('^')



    def pre_reg_tc_11_step_1to12(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 1 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 2 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('Yes - I am already enrolled.')
        self.VistA.wait('Yes - I would like to enroll.')
        self.VistA.wait('Yes - But I do not want to enroll right now.')
        self.VistA.wait('No - No one has spoken to me/I ')
        self.VistA.wait('No - I am not interested in enrolling.')
        self.VistA.wait('have a computer / internet access')
        self.VistA.wait('response:')
        self.VistA.write('1')
        # STEP 3
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team."')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        self.VistA.wait('Enrolled: YES')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('2')
        # STEP 4
        self.VistA.wait('Step 2 of 3: My HealtheVet Authentication Upgrade')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With an Authenticated MHV account patients can view VA appointments,')
        self.VistA.wait('lab results and VA medical records online."')
        self.VistA.wait('Select (Y) YES if patient already has an Authenticated MHV account')
        self.VistA.wait('Select (A) ACTION if patient would like to upgrade to Authenticated MHV account.')
        self.VistA.wait('Select (N) NO if patient refuses an Authenticated MHV account.')
        self.VistA.wait('(Yes/No/(A)ction):')
        self.VistA.write('YES')
        # STEP 5
        self.VistA.wait('Step 3 of 3: My HealtheVet Secure Messaging')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With Secure Messaging, Veterans can communicate online with VA health')
        self.VistA.wait('care teams about health questions, to request prescription renewals,')
        self.VistA.wait('or schedule appointments."')
        self.VistA.wait('Secure Messaging? (Yes/No/(A)ction):')
        self.VistA.write('N')
        # STEP 6
        self.VistA.wait('1 - No one has spoken to me/I ')
        self.VistA.wait('2 - I am not interested.')
        self.VistA.wait('3 - I do not have a computer.')
        self.VistA.wait('4 - I do not have access to the internet')
        self.VistA.wait('5 - I do not trust the internet.')
        self.VistA.wait('6 - My caregiver makes these decisions for me.')
        self.VistA.wait('7 - I do not see the benefit.')
        self.VistA.wait('8 - I would not use it often enough.')
        self.VistA.wait('9 - Other')
        self.VistA.wait('Select reason not using secure messaging:')
        self.VistA.write('9')
        self.VistA.wait('Other Reason Text')
        self.VistA.write('Something else')
        # STEP 7 (Verify)
        self.VistA.wait('Secure Messaging: NO')
        self.VistA.wait('Reason: Other - Something else')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('3')
        # STEP 8
        self.VistA.wait('Step 3 of 3: My HealtheVet Secure Messaging')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With Secure Messaging, Veterans can communicate online with VA health')
        self.VistA.wait('care teams about health questions, to request prescription renewals,')
        self.VistA.wait('or schedule appointments."')
        self.VistA.wait('Secure Messaging? (Yes/No/(A)ction):')
        self.VistA.write('A')
        # STEP 9
        self.VistA.wait('Action(s) taken today to assist patient with My HealtheVet enrollment.')
        self.VistA.wait('Referred patient to MHV coordinator for assistance.')
        self.VistA.wait('Gave patient instructions to set up their secure messaging at')
        self.VistA.wait('home or at kiosk')
        self.VistA.wait('Patient had a MHV account issue. Provided MHV Help Desk toll')
        self.VistA.wait('free #1-877-327- 0022, Mon-Fri, 8 a.m.-8 p.m. (EST)')
        self.VistA.wait('Helped patient set up their secure messaging account.')
        self.VistA.wait('Select an action:')
        self.VistA.write('1')
        # STEP 10
        self.VistA.wait('Actions Selected:')
        self.VistA.wait('Referred patient to MHV coordinator for assistance')
        self.VistA.wait('(A)dd another, (D)elete an action, or <RET> to save and exit:')
        self.VistA.write('')
        # STEP 11
        self.VistA.wait('Secure Messaging: ACTION/IN PROGRESS')
        self.VistA.wait('Action: Referred patient to MHV coordinator')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        # STEP 12
        self.VistA.wait('exit:')
        self.VistA.write('^')

    def pre_reg_tc_11_step_13to16(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 13 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Recent My HealtheVet actions taken by VistA Clerks')
        self.VistA.wait('MHV Enrollment confirmed')
        self.VistA.wait('MHV Authenticated Upgrade confirmed.')
        #self.VistA.wait('Referred patient to MHV coordinator for assistance')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 14
        self.VistA.wait('Enrolled: YES')
        self.VistA.wait('Authenticated: YES')
        self.VistA.wait('Secure Messaging: ACTION/IN PROGRESS')
        self.VistA.wait('Action: Referred patient to MHV coordinator for')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('3')
        # STEP 15
        self.VistA.wait('Step 3 of 3: My HealtheVet Secure Messaging')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With Secure Messaging, Veterans can communicate online with VA health')
        self.VistA.wait('care teams about health questions, to request prescription renewals,')
        self.VistA.wait('or schedule appointments."')
        self.VistA.wait('Secure Messaging? (Yes/No/(A)ction):')
        self.VistA.write('^')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue')
        self.VistA.write('')
        # STEP 16
        self.VistA.wait('exit:')
        self.VistA.write('^')


    def pre_reg_tc_11_step_13to16_Action_NO(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 13 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Recent My HealtheVet actions taken by VistA Clerks')
        self.VistA.wait('MHV Enrollment confirmed')
        self.VistA.wait('MHV Authenticated Upgrade confirmed.')
        #self.VistA.wait('Referred patient to MHV coordinator for assistance')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 14
        self.VistA.wait('Enrolled: YES')
        self.VistA.wait('Authenticated: YES')
        self.VistA.wait('Secure Messaging: ACTION/IN PROGRESS')
        self.VistA.wait('Action: Referred patient to MHV coordinator for')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('3')
        # STEP 15
        self.VistA.wait('Step 3 of 3: My HealtheVet Secure Messaging')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With Secure Messaging, Veterans can communicate online with VA health')
        self.VistA.wait('care teams about health questions, to request prescription renewals,')
        self.VistA.wait('or schedule appointments."')
        self.VistA.wait('Secure Messaging? (Yes/No/(A)ction)')
        self.VistA.write('A')
        self.VistA.wait('Action(s) taken today to assist patient with My HealtheVet enrollment.')
        self.VistA.wait('Referred patient to MHV coordinator for assistance.')
        self.VistA.wait('Gave patient instructions to set up their secure messaging at')
        self.VistA.wait('home or at kiosk')
        self.VistA.wait('Patient had a MHV account issue. Provided MHV Help Desk toll')
        self.VistA.wait('free #1-877-327- 0022, Mon-Fri, 8 a.m.-8 p.m. (EST)')
        self.VistA.wait('Helped patient set up their secure messaging account.')
        self.VistA.wait('Select an action:')
        self.VistA.write('^')
        self.VistA.wait('My HealtheVet enrollment questions is required to continue with this patient.')
        self.VistA.wait('Are you sure you want to quit')
        self.VistA.write('Y')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue')
        self.VistA.write('')
        # STEP 16
        self.VistA.wait('exit:')
        self.VistA.write('^')


    def pre_reg_tc_12(self, ssn):
        ''' Pre-Register a new Patient and show My HealtheVet Questions'''
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('S $P(^DG(43,1,0),"^",37)=1')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('D ^XUP')
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('DGPRE PRE-REGISTER OPTION')
        self.VistA.wait('Preregister:')
        self.VistA.write(ssn)
        # STEP 1 - (Verify)
        self.VistA.wait('** PATIENT NEEDS TO ANSWER MY HEALTHEVET ENROLLMENT QUESTIONS **')
        self.VistA.wait('Patient is missing required My HealtheVet Enrollment information')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 2 - (Verify)
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"Has a health care team member encouraged you')
        self.VistA.wait('to enroll online for My HealtheVet?"')
        self.VistA.wait('Yes - I am already enrolled.')
        self.VistA.wait('Yes - I would like to enroll.')
        self.VistA.wait('Yes - But I do not want to enroll right now.')
        self.VistA.wait('No - No one has spoken to me/I ')
        self.VistA.wait('No - I am not interested in enrolling.')
        self.VistA.wait('have a computer / internet access')
        self.VistA.wait('response:')
        self.VistA.write('1')
        # STEP 3
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('"We are strongly encouraging patients to enroll online for a My HealtheVet')
        self.VistA.wait('account. With it you can refill VA prescriptions, view lab results and')
        self.VistA.wait('medical records, and securely email your health care team."')
        self.VistA.wait('Press RETURN to continue:')
        self.VistA.write('')
        # STEP 4
        self.VistA.wait('Enrolled: YES')
        self.VistA.wait('Select an Enrollment step, or RETURN to continue:')
        self.VistA.write('')
        # STEP 5
        self.VistA.wait('exit:')
        self.VistA.write('')
        # STEP 6
        self.VistA.wait('exit:')
        self.VistA.write('')
        # STEP 7
        #self.VistA.wait('Do you wish to request a HINQ inquiry')
        #self.VistA.write('NO')
        # STEP 8
        self.VistA.wait('Do you want to edit Patient Data?')
        self.VistA.write('NO')
        # STEP 9
        self.VistA.wait('Do you want to edit the Patient')
        self.VistA.write('NO')
        # STEP 10 - (Verify)
        self.VistA.wait('315- MHV ENROLLMENT STATUS MISSING')
        self.VistA.wait('DO YOU WANT TO UPDATE THESE INCONSISTENCIES NOW?')
        self.VistA.write('YES')
        while True:
            index = self.VistA.multiwait(['Step 2 of 3: My HealtheVet Authentication Upgrade','COVERED BY HEALTH INSURANCE','VETERAN (Y/N)?','SERVICE CONNECTED?','EMPLOYMENT STATUS','MARITAL STATUS','RELIGIOUS PREFERENCE','RELIGIOUS PREFERENCE','EMPLOYMENT STATUS','E-NAME','MAIDEN NAME','SOCIAL SECURITY NUMBER','RECEIVING A&A BENEFITS?','RECEIVING HOUSEBOUND BENEFITS?','RECEIVING A VA PENSION?'])
            if index == 0:
                break
            elif (index == 1) or (index == 4) or (index == 5):
                self.VistA.write('U')
            elif index == 2:
                self.VistA.write('YES')
            elif index == 3:
                self.VistA.write('NO')
            else:
                self.VistA.write('')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With an Authenticated MHV account patients can view VA appointments,')
        self.VistA.wait('lab results and VA medical records online."')
        self.VistA.wait('Select (Y) YES if patient already has an Authenticated MHV account')
        self.VistA.wait('Select (A) ACTION if patient would like to upgrade to Authenticated MHV account.')
        self.VistA.wait('Select (N) NO if patient refuses an Authenticated MHV account.')
        self.VistA.wait('(Yes/No/(A)ction):')
        self.VistA.write('YES')
        self.VistA.wait('Step 3 of 3: My HealtheVet Secure Messaging')
        self.VistA.wait('Please read the following to the patient')
        self.VistA.wait('With Secure Messaging, Veterans can communicate online with VA health')
        self.VistA.wait('care teams about health questions, to request prescription renewals,')
        self.VistA.wait('or schedule appointments."')
        self.VistA.wait('Select (Y) YES if patient already has an Authenticated MHV account')
        self.VistA.wait('Select (A) ACTION if patient would like to upgrade to Authenticated MHV account.')
        self.VistA.wait('Select (N) NO if patient refuses an Authenticated MHV account.')
        self.VistA.wait('Secure Messaging? (Yes/No/(A)ction)')
        self.VistA.write('YES')
        self.VistA.wait('TYPE: ')
        self.VistA.write('^')
        self.VistA.wait('DO YOU WANT TO UPDATE THESE INCONSISTENCIES NOW?')
        self.VistA.write('NO')
        self.VistA.wait('STATUS OF CALL:')
        self.VistA.write('\r\r')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('S $P(^DG(43,1,0),"^",37)=""')
        self.VistA.wait(self.VistA.prompt)


    def mhv_pats (self):
        '''Clear out all MHV fields from patients'''
        self.VistA.write('S DFN=0 F  S DFN=$O(^DPT(DFN)) Q:DFN>23  I $D(^DPT(DFN,2))!($D(^DPT(DFN,1))) K ^DPT(DFN,2),^DPT(DFN,1),^DPT(DFN,1,0),^DPT(DFN,1,1,0),^DPT(DFN,1,"B") W !,"Cleared Patient: ",DFN\r')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('')

    def startCoverage(self, routines=['*']):
        self.write('D ^%SYS.MONLBL')
        rval = self.multiwait(['Stop Monitor', 'Start Monitor'])
        if rval == 0:
            self.write('1')
            self.wait('Start Monitor')
            self.write('1')
        elif rval == 1:
            self.write('1')
        else:
            raise TestHelper.TestError('ERROR starting monitor, rbuf: ' + rval)
        for routine in routines:
            self.wait('Routine Name')
            self.write(routine)
        self.wait('Routine Name', tout=120)
        self.write('')
        self.wait('choice')
        self.write('2')
        self.wait('choice')
        self.write('1')
        self.wait('continue')
        self.write('\r')

    def stopCoverage(self, path, humanreadable='OFF'):
        newpath, filename = os.path.split(path)
        self.write('D ^%SYS.MONLBL')
        self.wait('choice')
        if humanreadable == 'ON':
            self.write('5')
            self.wait('summary')
            self.write('Y')
        else:
            self.write('6')
            self.wait('Routine number')
            self.write('*')
        self.wait('FileName')
        self.write(newpath + '/Coverage/' + filename.replace('.log', '.cmcov').replace('.txt', '.cmcov'))
        self.wait('continue')
        self.write('')
        self.wait('choice')
        self.write('1\r')

    def pre_reg_tc_MUnit(self):
        self.VistA.wait('OPTION NAME:')
        self.VistA.write('')
        self.VistA.wait(self.VistA.prompt)
        self.VistA.write('D ^ZZDGMHV1')
        self.VistA.wait(self.VistA.prompt)